@@ -14,10 +14,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 palette = [
-    ['body','dark blue', '', 'standout'],
+    ['body','default', '', 'standout'],
     ['focus','dark red', '', 'standout'],
     ['header','light blue', ''],
-    ['line', 'light blue', ''],
+    ['line', 'dark blue', ''],
     ['info_msg', 'dark green', ''],
     ['warn_msg', 'dark red', ''],
     ['current_tab', 'light blue', ''],
