@@ -27,6 +27,7 @@ from constant import palette
 from editor import TweetEditor
 from update import UpdateThread
 from widget import HeaderWidget
+from completion import Completion
 import urwid.html_fragment
 
 class Interface(object):
@@ -36,6 +37,7 @@ class Interface(object):
         self.conf       = tyrs.container['conf']
         self.timelines  = tyrs.container['timelines']
         self.buffers    = tyrs.container['buffers']
+        self.completion = tyrs.container['completion']
         self.help = False
         tyrs.container.add('interface', self)
         self.update_last_read_home()
@@ -110,6 +112,8 @@ class Interface(object):
     def lazzy_load(self):
         timeline = self.select_current_timeline()
         focus = timeline.timeline.get_focus()[1]
+        if timeline.cleared != False:
+            return
         if focus is len(timeline.walker)-1:
             timeline.page += 1
             statuses = self.api.retreive_statuses(self.buffer, timeline.page)
@@ -151,9 +155,9 @@ class Interface(object):
 
     def clear_statuses(self):
         timeline = self.select_current_timeline()
-        timeline.statuses = [timeline.statuses[0]]
         timeline.count_statuses()
         timeline.reset()
+        timeline.clear()
 
     def current_status(self):
         focus = self.listbox.get_focus()[0]
