@@ -18,12 +18,14 @@
    Tyrs
 
    @author:     Nicolas Paris <nicolas.caen@gmail.com>
-   @version:    0.6.1
-   @date:       18/12/2011
+   @date:       23/12/2011
    @licence:    GPLv3
 
+
 '''
 
+__revision__ = "0.6.2"
+
 import sys
 import utils
 import config
@@ -35,6 +37,7 @@ from urllib2 import URLError
 from timeline import Timeline
 from container import Container
 from interface import Interface
+from completion import Completion
 
 locale.setlocale(locale.LC_ALL, '')
 container =  Container()
@@ -51,6 +54,8 @@ def arguments():
             help='Use another configuration file.')
     parser.add_argument('-g', '--generate-config',
             help='Generate a default configuration file.')
+    parser.add_argument('-v', '--version', action='version', version='Tyrs %s' % __revision__,
+            help='Show the current version of Tyrs')
     args = parser.parse_args()
     return args
 
@@ -93,6 +98,8 @@ def init_timelines():
         timelines[buff] = Timeline(buff)
     container.add('timelines', timelines)
     container.add('buffers', buffers)
+    completion = Completion()
+    container.add('completion', completion)
 
 if __name__ == "__main__":
     gettext.install('tyrs', unicode=1)
