@@ -17,7 +17,7 @@ import re
 import tyrs
 import time
 import urwid
-from utils import html_unescape, encode, get_source, get_urls
+from utils import html_unescape, encode, get_source, get_urls, get_exact_nick
 
 class HeaderWidget(urwid.WidgetWrap):
 
@@ -125,6 +125,8 @@ class StatusWidget (urwid.WidgetWrap):
                     ## @anyone
                     else:
                         result.append(('attag', word))
+                        tyrs.container['completion'].add(get_exact_nick(word))
+                        
                 else:
                     result.append(word)
         return result
@@ -147,7 +149,8 @@ class StatusWidget (urwid.WidgetWrap):
 
         if self.get_retweet_count(status):
             retweet_count = str(self.get_retweet_count(status))
-
+            
+        tyrs.container['completion'].add(get_exact_nick(nick))
         header_template = self.conf.params['header_template'] 
         header = unicode(header_template).format(
             time = timer,
@@ -230,7 +233,10 @@ class TitleLineBox(urwid.WidgetDecoration, urwid.WidgetWrap):
     def __init__(self, original_widget, title=''):
         """Draw a line around original_widget."""
 
+
         self.color = 'header'
+        if int(urwid.__version__[0]) == 1:
+            urwid.utf8decode = self.utf8decode
 
         tlcorner=None; tline=None; lline=None
         trcorner=None; blcorner=None; rline=None
@@ -264,3 +270,7 @@ class TitleLineBox(urwid.WidgetDecoration, urwid.WidgetWrap):
 
         urwid.WidgetDecoration.__init__(self, original_widget)
         urwid.WidgetWrap.__init__(self, pile)
+
+    def utf8decode(self, string):
+        return string
+
